Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(239)

Unified Diff: chrome/renderer/form_manager.h

Issue 3029061: AutoFill: Remove one level of indirection when clearing a previewed form. (Closed)
Patch Set: Fix test. Created 10 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/renderer/autofill_helper.cc ('k') | chrome/renderer/form_manager.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/renderer/form_manager.h
diff --git a/chrome/renderer/form_manager.h b/chrome/renderer/form_manager.h
index 352875772bafcb95c2a3318023c0afb55a46e75b..ce34f9a7d33cd4cc802b180c759840c8d55c3158 100644
--- a/chrome/renderer/form_manager.h
+++ b/chrome/renderer/form_manager.h
@@ -102,9 +102,9 @@ class FormManager {
bool ClearFormWithNode(const WebKit::WebNode& node);
// Clears the placeholder values and the auto-filled background for any fields
- // in |form| that have been previewed. Returns false if the form is not
- // found.
- bool ClearPreviewedForm(const webkit_glue::FormData& form);
+ // in the form containing |node| that have been previewed. Returns false if
+ // the form is not found.
+ bool ClearPreviewedFormWithNode(const WebKit::WebNode& node);
// Resets the stored set of forms.
void Reset();
« no previous file with comments | « chrome/renderer/autofill_helper.cc ('k') | chrome/renderer/form_manager.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698